.. warning::
    While fully usable, time2relax is still pre-1.0 software and has **no**
    backwards compatibility guarantees until the 1.0 release! Please make sure
    to read the changelog carefully **anytime you upgrade**!
